summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/engine/default.py
diff options
context:
space:
mode:
authorMike Bayer <mike_mp@zzzcomputing.com>2016-11-23 09:14:02 -0500
committerMike Bayer <mike_mp@zzzcomputing.com>2016-11-23 10:31:56 -0500
commit55ad10370f9eb50795e136aac595193168982e92 (patch)
tree2571e7b7d844dec8cb22cf475188e3ec65cb3184 /lib/sqlalchemy/engine/default.py
parent868e98bf407175b016e9e5cbc95bcf0cc859362a (diff)
downloadsqlalchemy-55ad10370f9eb50795e136aac595193168982e92.tar.gz
Add _extend_on deduplicating set for metadata.reflect()
The "extend_existing" option of :class:`.Table` reflection would cause indexes and constraints to be doubled up in the case that the parameter were used with :meth:`.MetaData.reflect` (as the automap extension does) due to tables being reflected both within the foreign key path as well as directly. A new de-duplicating set is passed through within the :meth:`.MetaData.reflect` sequence to prevent double reflection in this way. Change-Id: Ibf6650c1e76a44ccbe15765fd79df2fa53d6bac7 Fixes: #3861
Diffstat (limited to 'lib/sqlalchemy/engine/default.py')
-rw-r--r--lib/sqlalchemy/engine/default.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/sqlalchemy/engine/default.py b/lib/sqlalchemy/engine/default.py
index 719178f7e..ea3476295 100644
--- a/lib/sqlalchemy/engine/default.py
+++ b/lib/sqlalchemy/engine/default.py
@@ -366,9 +366,10 @@ class DefaultDialect(interfaces.Dialect):
return sqltypes.adapt_type(typeobj, self.colspecs)
def reflecttable(
self, connection, table, include_columns, exclude_columns):
insp = reflection.Inspector.from_engine(connection)
- return insp.reflecttable(table, include_columns, exclude_columns)
+ return insp.reflecttable(
+ table, include_columns, exclude_columns, **opts)
def get_pk_constraint(self, conn, table_name, schema=None, **kw):
"""Compatibility method, adapts the result of get_primary_keys()
@@ -366,9 +366,10 @@ class DefaultDialect(interfaces.Dialect):
return sqltypes.adapt_type(typeobj, self.colspecs)
def reflecttable(
- self, connection, table, include_columns, exclude_columns):
+ self, connection, table, include_columns, exclude_columns, **opts):
insp = reflection.Inspector.from_engine(connection)